#
# CaA-census-fishing.R, 31 Mar 24

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(4)


comp_installs=function(df)
{
t=df[order(df$DATE), ]
lines(t$DATE, t$NUMBER.OF.INSTALLATIONS, col=t$col_str[1])
}


comp_unfilled=function(df)
{
t=df[order(df$DATE), ]
lines(t$DATE, t$NUMBER.OF.UNFILLED.ORDERS, col=t$col_str[1], lty=2)
}


n27=read.csv("n27.csv", as.is=TRUE)

n27$DATE=as.Date(n27$DATE, format="%b-%d-%Y")

# Fix some typos
n27$NUMBER.OF.INSTALLATIONS[n27$NUMBER.OF.INSTALLATIONS == "o"]=0
n27$NUMBER.OF.INSTALLATIONS[n27$NUMBER.OF.INSTALLATIONS == "I"]=1

n27$NUMBER.OF.INSTALLATIONS=as.numeric(n27$NUMBER.OF.INSTALLATIONS)
n27$NUMBER.OF.UNFILLED.ORDERS=as.numeric(n27$NUMBER.OF.UNFILLED.ORDERS)

n27$NAME.OF.COMPUTER[n27$NAME.OF.COMPUTER == "360/90 Series"]="360/90" # For consistency with other models

IBM=subset(n27, NAME.OF.MANUFACTURER == "IBM")
IBM360=subset(IBM, grepl("^360", IBM$NAME.OF.COMPUTER))

u_NoC=sort(unique(IBM360$NAME.OF.COMPUTER))
pal_col=rainbow(length(u_NoC))
IBM360$col_str=mapvalues(IBM360$NAME.OF.COMPUTER, u_NoC, pal_col)

plot(IBM360$DATE, IBM360$NUMBER.OF.INSTALLATIONS, type="n", log="y",
	xlab="Date", ylab="Installations")


legend("topleft", legend=u_NoC,
                        fill=pal_col, border="white", bty="n")

d_ply(IBM360, .(NAME.OF.COMPUTER), comp_installs)

# d_ply(IBM360, .(NAME.OF.COMPUTER), comp_unfilled)

dev.copy(dev=png, file="IBM360-installations.png")
dev.off()

