#
# mergecsv.awk, 31 Mar 24

BEGIN {
	skip=0
	}

$0 == "" {
	next
	}

$0 == ",,," ||
$0 == ",,,," ||
$0 == ",,,,," ||
$0 == ",,,,,," ||
$0 == ",,,,,,," ||
$0 == ",,,,,,,," {
	next
	}

$1 == "'Confidence" {
	skip=1
	next
	}

$0 ~ /^"'NAME OF","'NAME OF"/ {
	print "\"NAME OF MANUFACTURER\",\"NAME OF COMPUTER\",\"DATE OF FIRST INSTALLATION\",\"AVERAGE OR RANGE OF MONTHLY RENTAL\",\"NUMBER OF INSTALLATIONS In U.S.A.\",\"NUMBER OF INSTALLATIONS Outside U.S.A.\",\"NUMBER OF INSTALLATIONS In World\",\"NUMBER OF UNFILLED ORDERS\""
	next
	}

$0 ~ / no longer in production/ ||
$0 ~ /COMPUTERS and AUTOMATION/ ||
$0 ~ /^"'","'","'DATE OF"/ || # Table header split across multiple lines
$0 ~ /^"'Part I/ ||
$0 ~ /"'I\\. United States Manufacturers","'",/ ||
$0 ~ /"'II\\. Non-United States Manufacturers","'",/ ||
$0 ~ /"'II\\. Non-U\\.S","'Manufacturers",/ ||
$0 ~ /"'MANUFACTURER","'COMPUTER",/ ||
$0 ~ /"'","'","'","'Combined, TOTAL",/ ||
$0 ~ /"'","'","'","'","'TOTALS"/ ||
$0 ~ /"'X","'","'","'","'TOTALS"/ ||
$0 ~ /"'","'","'","'","'","'","'"/ {
	next
	}

skip == 0 {
	gsub("-210,211", "-210, 211", $0) # Special case
	gsub("\"'", "\"", $0)  # ' inserted at the start of every column
	gsub("\\$ ", "", $0)  # $ on dollar amounts
	gsub("\\$", "", $0)  # $ on dollar amounts
	gsub("£", "", $0)  # $ on UK pound amounts
	gsub(",$", "", $0) # remove trailing comma
	gsub("\"-\"", "\"NA\"", $0) # information not obtained at press time, hang onto " for now
	gsub("\"--\"", "\"NA\"", $0) # information not obtained at press time, hang onto " for now
	gsub("\"---\"", "\"NA\"", $0) # information not obtained at press time, hang onto " for now
	gsub("\"X\"", "\"0\"", $0) # no longer in production
	gsub("\"y\"", "\"Y\"", $0) # no longer in production
	gsub("\"n\"", "\"N\"", $0) # no longer in production
	gsub(" \\(cont'd)", "", $0) # entry continued on next page
	gsub(" \\(cont's d)", "", $0) # entry continued on next page
	gsub(" \\(con'd)", "", $0) # entry continued on next page
	gsub("\\(cont'd)", "", $0) # entry continued on next page
	gsub("\\(cont'd", "", $0) # entry continued on next page
	gsub(" \\(cont d)", "", $0) # entry continued on next page
	gsub(" \\(cont d\\.)", "", $0) # entry continued on next page
	gsub(" \\(contd)", "", $0) # entry continued on next page
	gsub(" \\(contd\\.)", "", $0) # entry continued on next page
	gsub(" \\(contd)\\.", "", $0) # entry continued on next page
	gsub("\"\\(contd)", "", $0) # entry continued on next page
	gsub(" \\(cont\\.)", "", $0) # entry continued on next page
	gsub(" \\(contd", "", $0) # entry continued on next page
	gsub("\\(contd", "", $0) # entry continued on next page
	gsub("\\(cont\\.)", "", $0) # entry continued on next page
	gsub("\\(cont\\. )", "", $0) # entry continued on next page
	gsub(" \\(cont", "", $0) # entry continued on next page
	gsub(" \\(cond)\"", "\"", $0) # entry continued on next page
	gsub(" \\(Contd)", "", $0) # entry continued on next page
	gsub("International Bus\\. Mach\\. Corp.", "IBM", $0) # company abbreviation
	gsub("International Bus\\.Mach\\. Corp.", "IBM", $0) # company abbreviation
	gsub(" \\(N)\"", "\"", $0) # manufacturer refuses to give any figures
	gsub(" \\(R)\"", "\"", $0) # figures derived in part from information released directly
	gsub(" \\(R) ", "", $0) # figures derived in part from information released directly
	gsub("\\.\"", "\"", $0) #  abbreviation not always terminated by a period

	gsub("\\.\\. )", "", $0) # Typos
	gsub("\\. \\.)", "", $0) # Typos
	gsub("Process Control Computers:", "", $0) # GE computers used for a particular purpose

	gsub("Bi zmac", "Bizmac", $0) # Typos
	gsub("Bi izmac", "Bizmac", $0) # Typos
	gsub("Bizma C", "Bizmac", $0) # Typos
	gsub("2000-210211", "2000-210, 211", $0) # Typos
	gsub("\"-210, 211", "\"2000-210, 211", $0) # Typos
	gsub("\"-210211", "\"2000-210, 211", $0) # Typos
	gsub("1620 I\\. II", "1620 I, II", $0) # Typos
	gsub("90 1, II", "90 I, II", $0) # Typos
	gsub("60 E 120", "60, 120", $0) # Typos
	gsub("60 & 120", "60, 120", $0) # Typos
	gsub("90, E Step", "90, \\& Step", $0) # Typos
	gsub("160\\*/8090", "160/8090", $0) # Typos
	gsub("- 3", "3", $0) # Typos
	gsub("NCR - 1", "NCR-1", $0) # Typos
	gsub("NCR 1", "NCR-1", $0) # Typos
	gsub("NCR 3", "NCR-3", $0) # Typos
	gsub("NCR 5", "NCR-5", $0) # Typos
	gsub("NCR390", "NCR-390", $0) # Typos
	gsub("310 \\*", "310", $0) # Typos
	gsub("PB \\.1\\.10", "PB 440", $0) # Typos
	gsub("Compu ters", "Computers", $0) # Typos
	gsub("DATA-matic", "DATAmatic", $0) # Typos
	gsub("DATAmatic\",\"1000 ", "DATAmatic 1000\",\"", $0) # Typos
	gsub("Deuce", "DEUCE", $0) # Typos
	gsub("\"H-400-\"", "\"H-400\"", $0) # Typos
	gsub("\"N Sold\",\"", "\"N\",\"Sold ", $0) # Typos
	gsub("H--8", "H-8", $0) # Typos
	gsub("IndustrieP1000", "P1000", $0) # Typos
	gsub("\"Mode 2", "\"Model 2", $0) # Typos
	gsub("Myriad I/I", "Myriad II", $0) # Typos
	gsub("NAIR 1", "NAIRI", $0) # Typos
	gsub("RPC4000", "RPC-4000", $0) # Typos
	gsub("SEL 8", "SEL-8", $0) # Typos
	gsub("SIGMA 7", "Sigma 7", $0) # Typos
	gsub("S-Two", "S-2", $0) # Typos
	gsub("Solid-State 80 I\\. II", "Solid-State 80 I, II", $0) # Typos
	gsub("SYSTEM 4", "System 4", $0) # Typos
	gsub("\"\\.6\"", "\"6\"", $0) # Typos
	gsub("\"\\.9\"", "\"9\"", $0) # Typos
	gsub("\"\\.118\"", "\"118\"", $0) # Typos
	gsub("\"\\.205\"", "\"205\"", $0) # Typos
	gsub("\"0\",\"Y\"$", "\"0\",\"9\"", $0) # Typos Burroughs B 5000, Jan 20 1963
	gsub("\"0\",\"I\"$", "\"0\",\"1\"", $0) # Typos Dec 10 1965, Aug 10 1966
	gsub("2000-210\\. 211", "2000-210, 211", $0) # Typos
	gsub("70, 2\\. 4", "70, 2, 4", $0) # Typos
	gsub("7070, 24", "7070, 2, 4", $0) # Typos
	gsub("7070,2", "7070, 2", $0) # Typos
	gsub("90,1,II,", "90, I, II", $0) # Typos
	gsub("90\\.", "90,", $0) # Typos
	gsub("90, I, II,", "90, I, II", $0) # Typos
	gsub("IC6000", "IC 6000", $0) # Typos
	gsub("7094 II", "7094-II", $0) # Typos
	gsub("Leo 1,", "LEO 1,", $0) # Typos
	gsub("\"1 BM\"", "\"IBM\"", $0) # Typos
	gsub("\"TBM\"", "\"IBM\"", $0) # Typos
	gsub("AI1", "All, 2", $0) # Typos
	gsub("Addressograph-Multigra ", "Addressograph-Multigraph ", $0) # Typos
	gsub("Addressograph-Multigrap ", "Addressograph-Multigraph ", $0) # Typos
	gsub("AS Regne Centralen", "A/S Regnecentralen", $0) # Typos
	gsub("Atlas 1 E 2", "Atlas 1 \\& 2", $0) # Typos
	gsub("Control Dystems", "Control Systems", $0) # Typos
	gsub("Data General Corp\\. ", "Data General Corp", $0) # Typos
	gsub("DIGIAC", "Digiac", $0) # Typos
	gsub("Digital Electronics Inc\\.", "Digital Electronics Inc", $0) # Typos
	gsub("Digital`Equipment", "Digital Equipment", $0) # Typos
	gsub("Computer Control Division", "Honeywell EDP", $0) # Typos
	gsub("Computer Control Div\"", "Honeywell EDP\"", $0) # Typos
	gsub("EDP Division", "Honeywell EDP", $0) # Typos
	gsub("EDP Div", "Honeywell EDP", $0) # Typos
	gsub("\"Div\\.\"", "Honeywell EDP\"", $0) # Typos
	gsub("Elbit Computers Ltd\\.", "Elbit Computers Ltd", $0) # Typos
	gsub("ELLIOTT", "Elliott", $0) # Typos
	gsub("EMR Computer\"", "EMR Computer Div\"", $0) # Typos
	gsub("HRB Singer", "HRB-Singer", $0) # Typos
	gsub("II-W Electronics", "H-W Electronics", $0) # Typos
	gsub("Electronic Assoc\\. Inc", "Electronic Associates", $0) # Typos
	gsub("English Electric Computers Ltd\\. ", "English Electric Computers", $0) # Typos
	gsub("Honeywell\\(\"", "Honeywell EDP\"", $0) # Typos
	gsub("Honeywell\"", "Honeywell EDP\"", $0) # Typos
	gsub("Honeywel\"", "Honeywell EDP\"", $0) # Typos
	gsub("Honeywell, Computer Control", "Honeywell EDP", $0) # Typos
	gsub("Honeywell Electronic Data Processing", "Honeywell EDP", $0) # Typos
	gsub("Honeywell Electronic Data", "Honeywell EDP", $0) # Typos
	gsub("\\(See International Computers,\",\"Ltd\\.)", "\",\"", $0) # Typos
	gsub("International Computers, Ltd\\. \\(ICL)", "International Computers", $0) # Typos
	gsub("International Computers,\"", "International Computers\"", $0) # Typos
	gsub("^\"Processing\"", "\"Honeywell EDP\"", $0) # Typos
	gsub("^\"Instruments\"", "\"Advanced Scientific Instruments\"", $0) # Typos
	gsub("Hewlett Packard", "Hewlett-Packard", $0) # Typos
	gsub("Norsk Data-Elektronikk ", "Norsk Data Elektronikk", $0) # Typos
	gsub("Norsk Data-Elektronikk", "Norsk Data Elektronikk", $0) # Typos
	gsub("UNI\\.VAC", "UNIVAC", $0) # Typos
	gsub("Remington-Rand UNIVAC", "UNIVAC", $0) # Typos
	gsub("UNIVAC, \\(Div\\. of Sperry Rand)", "UNIVAC", $0) # Typos
	gsub("UNIVAC \\(Div\\. of Sperry Rand)", "UNIVAC", $0) # Typos
	gsub("UNIVAC, Div\\. of Sperry Rand", "UNIVAC", $0) # Typos
	gsub("UNIVAC, Div\\.of Sperry Rand", "UNIVAC", $0) # Typos
	gsub("\\*PDP", "PDP", $0) # Typos
	gsub("Philips' Computer", "Philips Computer", $0) # Typos
	gsub("Philips Computer Industrie ", "Philips Computer", $0) # Typos
	gsub("N\\.V\\.Philips Computer", "N.V. Philips Computer", $0) # Typos
	gsub("Potter Instrument Co\\.\\.", "Potter Instrument Co", $0) # Typos
	gsub("Potter Instrument Co\\. Inc\\.", "Potter Instrument Co", $0) # Typos
	gsub("Potter Instrument Co\\.", "Potter Instrument Co", $0) # Typos
	gsub("Radio Corporation of America", "RCA", $0) # Typos
	gsub("Radio Corp of America", "RCA", $0) # Typos
	gsub("Radio Corp\\. of America", "RCA", $0) # Typos
	gsub("Scientific Data Syst Inc", "Scientific Data Systems, Inc", $0) # Typos
	gsub("Scientific Data Syst\\., Inc", "Scientific Data Systems, Inc", $0) # Typos
	gsub("Scientific Data Syst\\. Inc", "Scientific Data Systems, Inc", $0) # Typos
	gsub("Scientific Data Syst\\.", "Scientific Data Systems, Inc", $0) # Typos
	gsub("Scientific Data Systems\"", "Scientific Data Systems, Inc\"", $0) # Typos
	gsub("Scientific Data Systems Inc", "Scientific Data Systems, Inc", $0) # Typos
	gsub("Systems Inc\\.", "Systems Inc", $0) # Typos
	gsub("Thompson Ramo Wooldridge Inc", "Thompson Ramo Wooldridge, Inc", $0) # Typos
	gsub("Electronic Assoc Inc", "Electronic Associates, Inc", $0) # Typos
	gsub("Electronic Assoc\\., Inc", "Electronic Associates, Inc", $0) # Typos
	gsub("Electronic Assoc\\.\\. Inc", "Electronic Associates, Inc", $0) # Typos
	gsub("Advanced Scientific\"", "Advanced Scientific Instruments\"", $0) # Typos
	gsub("Control Data Corporation", "Control Data Corp", $0) # Typos
	gsub("Scientific Control Corporation", "Scientific Control Corp", $0) # Typos
	gsub("Tabulators Ltd", "International Computers and", $0) # Typos
	gsub("GEC-AEI Automation Ltd\\.", "G.E.C. Computers", $0) # Typos
	gsub("GEC-AEI Automation Ltd", "G.E.C. Computers", $0) # Typos
	gsub("G\\.E\\.C\\. Computers & Automation", "G.E.C. Computers", $0) # Typos
	gsub("G\\.E\\.C\\. Computers & Automa-", "G.E.C. Computers", $0) # Typos
	gsub("tion Ltd", "G.E.C. Computers", $0) # Typos
	gsub("The Marconi Co\\., Ltd", "Marconi Co", $0) # Typos
	gsub("The Marconi Co\\.,", "Marconi Co", $0) # Typos
	gsub("The Marconi Co", "Marconi Co", $0) # Typos
	gsub("Marconi Co\\. Ltd", "Marconi Co", $0) # Typos
	gsub("Marconi Co\\. ", "Marconi Co", $0) # Typos
	gsub("^\"Ltd\"", "\"\"", $0) # Continuation of company name on newline
	gsub("^\"Limited\"", "\"\"", $0) # Continuation of company name on newline
	gsub("Union of Soviet Socialist", "USSR", $0) # Continuation of company name on newline
	gsub("^\"Republics\"", "\"\"", $0) # Continuation of company name on newline
	gsub("^\"\\(A)\"", "\"\"", $0) # Continuation of company name on newline
	gsub(" \\(A) \\(8/69)", "", $0) # Continuation of company name on newline
	gsub(" \\(A) \\(May 1969)", "", $0) # Continuation of company name on newline
	gsub("\\(A) \\(May 1969)", "", $0) # Continuation of company name on newline
	gsub(" \\(A) \\(Sept\\. 1969)", "", $0) # Continuation of company name on newline
	gsub("\\(A) \\(Sept\\. 1969)", "", $0) # Continuation of company name on newline
	gsub(" \\(A) \\(Nov\\. 1969)", "", $0) # Continuation of company name on newline
	gsub("\"\\(N)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(N) \\(D)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(N) \\(Jan\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(N) \\(Aug\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(N) \\(1/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(N) \\(8/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(R)\"", "\"\"", $0) # Continuation of company name on newline
	gsub(" \\(N) \\(1/69)", "", $0) # Continuation of company name on newline
	gsub("\"\\(1/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(5/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(6/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(9/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(10/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(1/69-4/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(1/69-5/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(2/69-4/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(2/69-5/69)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Jan\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(May 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(July 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Aug\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Aug 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Sept\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Nov\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Jan\\.-Apr\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Jan\\.-May\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Jan\\.-May 1969)\"", "\"\"", $0) # Continuation of company name on newline
	gsub("\"\\(Feb\\.-Apr\\. 1969)\"", "\"\"", $0) # Continuation of company name on newline

	gsub(", Inc", "", $0) # For naming consistency
	gsub(" Inc", "", $0) # For naming consistency
	gsub("\" ", "\"", $0) # Leading space
	gsub(" \"", "\"", $0) # Trailing space

	gsub("INSTAL- LATIONS", "INSTALLATIONS", $0) # Typos
	gsub("MANUF ACTURER", "MANUFACTURER", $0) # Typos
	gsub("MANDFACTURER", "MANUFACTURER", $0) # Typos
	gsub("STATE STATE", "SOLID STATE", $0) # Typos
	gsub("UNF ILLED ORDERS", "UNFILLED ORDERS", $0) # Typos
	gsub("UNFILLED ORDERS\\*\\*", "UNFILLED ORDERS", $0) # Typos
	gsub("UNFILLED ORDERS\"\"\"", "UNFILLED ORDERS\"", $0) # Typos
	gsub("UNFILLED ORDERS\\*", "UNFILLED ORDERS", $0) # Typos
	gsub("NUMBER UNFILLED", "NUMBER OF UNFILLED", $0) # Typos
	gsub("MONTHLY RENTALS", "MONTHLY RENTAL", $0) # Typos
	gsub("RENTAL \\(S: SALE ONLY)", "RENTAL", $0) # Typos

	gsub(" \\(ex-\"", "\"", $0) # except...
	gsub(" \\(except\"", "\"", $0) # except...
	gsub("160A\\*", "160A", $0) # Cleanups
	gsub(" \\(formerly Digital", "", $0) # except...
	gsub("Electronics Inc\\.)\\.  \\(A) \\(May 1969)", "", $0) # except...
	gsub("\\(A) \\(June 1969)", "", $0) # except...

	gsub("Anaheim, Calif\\.", "", $0) # company address
	gsub("Anaheim, Calif", "", $0) # company address
	gsub("Anahcim, Calif", "", $0) # company address
	gsub("Apeldoorn, Netherlands", "", $0) # company address
	gsub("Apeldoorn\\. Netherlands", "", $0) # company address
	gsub("Boston, Mass\\.", "", $0) # company address
	gsub("Canoga Park, Calif\\.", "", $0) # company address
	gsub("Canoga Park, Calif", "", $0) # company address
	gsub("Canoga Park,", "", $0) # company address
	gsub("Chelmsford, Essex, England", "", $0) # company address
	gsub("Cherry Hill, N.J\\.", "", $0) # company address
	gsub("Cherry Hill, N.J", "", $0) # company address
	gsub("Cherry Hill\\. N.J", "", $0) # company address
	gsub("Cherry Hill,", "", $0) # company address
	gsub("Copenhagen, Denmark", "", $0) # company address
	gsub("Copenhagen. Denmark", "", $0) # company address
	gsub("Cupertino, Calif\\.", "", $0) # company address
	gsub("Cupertino, Calif", "", $0) # company address
	gsub("Dayton, Ohio", "", $0) # company address
	gsub("Dallas, Texas", "", $0) # company address
	gsub("Dallas, Tex\\.", "", $0) # company address
	gsub("Dallas, Tex", "", $0) # company address
	gsub("Detroit, Mich\\.", "", $0) # company address
	gsub("Detroit, Mich", "", $0) # company address
	gsub("Detroit,", "", $0) # company address
	gsub("E1 Segundo, Calif\\.", "", $0) # company address
	gsub("E1 Segundo, Calif", "", $0) # company address
	gsub("Framingham, Mass\\.", "", $0) # company address
	gsub("Framingham, Mass", "", $0) # company address
	gsub("Ft. Lauderdale, Fla\\.", "", $0) # company address
	gsub("Ft. Lauderdale, Fla", "", $0) # company address
	gsub("Ft. Lauderdale\\. Fla", "", $0) # company address
	gsub("Ft. Lauderdale,", "", $0) # company address
	gsub("Haifa, Israel", "", $0) # company address
	gsub("Haifa\\. Israel", "", $0) # company address
	gsub("Hudson, Mass\\.", "", $0) # company address
	gsub("Hudson, Mass", "", $0) # company address
	gsub("Linkoping, Sweden", "", $0) # company address
	gsub("Long Branch, N\\.J\\.", "", $0) # company address
	gsub("Long Branch, N\\.J", "", $0) # company address
	gsub("London, England", "", $0) # company address
	gsub("Los Angeles, Calif\\.", "", $0) # company address
	gsub("Los Angeles, Calif", "", $0) # company address
	gsub("Los Angeles\\. Calif", "", $0) # company address
	gsub("Maynard, Mass\\.", "", $0) # company address
	gsub("Maynard, Mass", "", $0) # company address
	gsub("Maynard,", "", $0) # company address
	gsub("Munich, Germany", "", $0) # company address
	gsub("Minneapolis, Minn\\.", "", $0) # company address
	gsub("Minneapolis, Minn", "", $0) # company address
	gsub("Minneapolis,", "", $0) # company address
	gsub("New York, N\\.Y\\.", "", $0) # company address
	gsub("New York, N\\.Y", "", $0) # company address
	gsub("New York,", "", $0) # company address
	gsub("New Parks, Leicester, England", "", $0) # company address
	gsub("New Parks,", "", $0) # company address
	gsub("Newport Beach, Calif\\.", "", $0) # company address
	gsub("Newport Beach, Calif", "", $0) # company address
	gsub("Newport Beach,", "", $0) # company address
	gsub("Oceanport, N\\.J\\.", "", $0) # company address
	gsub("Oceanport, N\\.J", "", $0) # company address
	gsub("Oceanport,", "", $0) # company address
	gsub("Oslo, Norway", "", $0) # company address
	gsub("Palo Alto, Calif\\.", "", $0) # company address
	gsub("Palo Alto, Calif", "", $0) # company address
	gsub("Plainview, N\\.Y\\.", "", $0) # company address
	gsub("Plainview, N\\.Y", "", $0) # company address
	gsub("Phoenix, Ariz\\.", "", $0) # company address
	gsub("Phoenix, Ariz", "", $0) # company address
	gsub("Phoenix, Arix\\.", "", $0) # company address
	gsub("Phoenix, Arix", "", $0) # company address
	gsub("Phoenix,", "", $0) # company address
	gsub("Santa Ana, Calif\\.", "", $0) # company address
	gsub("Santa Ana, Calif", "", $0) # company address
	gsub("Santa Ana\\. Calif", "", $0) # company address
	gsub("Santa Ana,", "", $0) # company address
	gsub("Santa Monica, Calif\\.", "", $0) # company address
	gsub("Santa Monica, Calif", "", $0) # company address
	gsub("Santa Monica\\. Calif", "", $0) # company address
	gsub("Santa Monica,", "", $0) # company address
	gsub("Southboro, Mass\\.", "", $0) # company address
	gsub("Wellesley Hills, Mass\\.", "", $0) # company address
	gsub("Wellesley Hills, Mass", "", $0) # company address
	gsub("Wellesley Hills,", "", $0) # company address
	gsub("Wembley, Middlesex, England", "", $0) # company address
	gsub("Wembley,", "", $0) # company address
	gsub("Wickliffe, Ohio", "", $0) # company address
	gsub("Willow Grove, Pa\\.", "", $0) # company address
	gsub("Willow Grove, Pa", "", $0) # company address
	gsub("Willow Grove,", "", $0) # company address
	gsub("White Plains, N\\.Y\\.", "", $0) # company address
	gsub("White Plains, N\\.Y", "", $0) # company address
	gsub("White Plains,", "", $0) # company address
	l_str=gensub("([^\"]),\"", "\\1\"", "g", $0) # trailing comma
	l_str=gensub(/([0-9]),([0-9])/, "\\1\\2", "g", l_str) # remove trailing comma
	gsub("\"NA\"", "NA", l_str) # Finally "NA" -> NA
	print l_str
	next
	}

